@@ -180,14 +180,14 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "LREADME.html",
-"encoder_guide.html#architecture_enc_src_proc",
-"group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a277526a4a9b8c413e870ee17ff986e87",
-"group__encoder.html#gga92b6709b58dc3435e3ba652da562eda1a621c3f07937527618dc06e962425f6cc",
-"structAV1Common.html#a6e6b41f076c157229d3bf1cdf2063975",
-"structCommonQuantParams.html#a6825895b20499860191f94b908be2f39",
-"structMB__MODE__INFO__EXT.html",
-"structTXB__RD__INFO.html#ae55655228fd53a8e1d4b9422f0a798de",
-"structaom__s__frame__info.html#a589b2fa70e546023fea1510c2973116a"
+"encoder_guide.html#architecture_entropy_coef",
+"group__aom__encoder.html#gadbb2fdd04ce113cdf455a6ea49109d41",
+"group__decoder.html#gab2bfd2f5517b9452d2c71b7c2b2e8e8d",
+"pickrst_8h_source.html",
+"structFIRSTPASS__INFO.html#a79971ac2f41950e2330721078f55cafd",
+"structPRIMARY__RATE__CONTROL.html#adc72a4c5ff33b9f70c6fbf24f54d478a",
+"structaom__codec__stream__info.html#af7487a0e56b6919f94a7e426abd44eac",
+"structmacroblock.html#a33908adcf2dd14dc20fd4ae6695fbdb0"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
